@@ -16,12 +16,39 @@ def test_init_with_url(request_get, channel_videos_html):
 
 
 @mock.patch('pytube.request.get')
-def test_channel_name(request_get, channel_videos_html):
+def test_channel_uri(request_get, channel_videos_html):
     request_get.return_value = channel_videos_html
 
     c = Channel('https://www.youtube.com/c/ProgrammingKnowledge/videos')
     assert c.channel_uri == '/c/ProgrammingKnowledge'
 
+    c = Channel('https://www.youtube.com/channel/UCs6nmQViDpUw0nuIx9c_WvA/videos')
+    assert c.channel_uri == '/channel/UCs6nmQViDpUw0nuIx9c_WvA'
+
+
+@mock.patch('pytube.request.get')
+def test_channel_name(request_get, channel_videos_html):
+    request_get.return_value = channel_videos_html
+
+    c = Channel('https://www.youtube.com/c/ProgrammingKnowledge/videos')
+    assert c.channel_name == 'ProgrammingKnowledge'
+
+
+@mock.patch('pytube.request.get')
+def test_channel_id(request_get, channel_videos_html):
+    request_get.return_value = channel_videos_html
+
+    c = Channel('https://www.youtube.com/c/ProgrammingKnowledge/videos')
+    assert c.channel_id == 'UCs6nmQViDpUw0nuIx9c_WvA'
+
+
+@mock.patch('pytube.request.get')
+def test_channel_vanity_url(request_get, channel_videos_html):
+    request_get.return_value = channel_videos_html
+
+    c = Channel('https://www.youtube.com/c/ProgrammingKnowledge/videos')
+    assert c.vanity_url == 'http://www.youtube.com/c/ProgrammingKnowledge'
+
 
 @mock.patch('pytube.request.get')
 def test_channel_video_list(request_get, channel_videos_html):
