@@ -5,18 +5,18 @@ import pytest
 @pytest.mark.parametrize(
     ("test_input", "expected"),
     [
-        ({"progressive": True}, [18, 22]),
+        ({"progressive": True}, [17, 18, 22]),
         ({"resolution": "720p"}, [22, 136, 247, 398]),
         ({"res": "720p"}, [22, 136, 247, 398]),
         ({"fps": 24, "resolution": "480p"}, [135, 244, 397]),
-        ({"mime_type": "audio/mp4"}, [140]),
-        ({"type": "audio"}, [140, 249, 250, 251]),
-        ({"subtype": "3gpp"}, []),
+        ({"mime_type": "audio/mp4"}, [139, 140]),
+        ({"type": "audio"}, [139, 140, 249, 250, 251]),
+        ({"subtype": "3gpp"}, [17]),
         ({"abr": "128kbps"}, [140]),
         ({"bitrate": "128kbps"}, [140]),
         ({"audio_codec": "opus"}, [249, 250, 251]),
         ({"video_codec": "vp9"}, [248, 247, 244, 243, 242, 278]),
-        ({"only_audio": True}, [140, 249, 250, 251]),
+        ({"only_audio": True}, [139, 140, 249, 250, 251]),
         ({"only_video": True, "video_codec": "avc1.4d4015"}, [133]),
         ({"adaptive": True, "resolution": "1080p"}, [137, 248, 399]),
         ({"custom_filter_functions": [lambda s: s.itag == 18]}, [18]),
@@ -50,7 +50,7 @@ def test_get_first(cipher_signature):
     """Ensure :meth:`~pytube.StreamQuery.first` returns the expected
     :class:`Stream <Stream>`.
     """
-    assert cipher_signature.streams[0].itag == 18
+    assert cipher_signature.streams.first().itag == cipher_signature.streams[0].itag
 
 
 def test_order_by(cipher_signature):
@@ -61,7 +61,13 @@ def test_order_by(cipher_signature):
         s.itag
         for s in cipher_signature.streams.filter(type="audio").order_by("itag")
     ]
-    assert itags == [140, 249, 250, 251]
+    expected_itags = [
+        s.itag
+        for s in cipher_signature.streams.filter(type="audio")
+    ]
+    expected_itags.sort()
+
+    assert itags == expected_itags
 
 
 def test_order_by_descending(cipher_signature):
@@ -75,7 +81,12 @@ def test_order_by_descending(cipher_signature):
         .order_by("itag")
         .desc()
     ]
-    assert itags == [251, 250, 249, 140]
+    expected_itags = [
+        s.itag
+        for s in cipher_signature.streams.filter(type="audio")
+    ]
+    expected_itags.sort(reverse=True)
+    assert itags == expected_itags
 
 
 def test_order_by_non_numerical(cipher_signature):
@@ -99,7 +110,11 @@ def test_order_by_ascending(cipher_signature):
         .order_by("itag")
         .asc()
     ]
-    assert itags == [140, 249, 250, 251]
+    expected_itags = [
+        s.itag
+        for s in cipher_signature.streams.filter(type="audio")
+    ]
+    assert itags == expected_itags
 
 
 def test_order_by_non_numerical_ascending(cipher_signature):
@@ -114,7 +129,16 @@ def test_order_by_non_numerical_ascending(cipher_signature):
 
 def test_order_by_with_none_values(cipher_signature):
     abrs = [s.abr for s in cipher_signature.streams.order_by("abr").asc()]
-    assert abrs == ["50kbps", "70kbps", "96kbps", "128kbps", "160kbps", "192kbps"]
+    assert abrs == [
+        "24kbps",
+        "48kbps",
+        "50kbps",
+        "70kbps",
+        "96kbps",
+        "128kbps",
+        "160kbps",
+        "192kbps"
+    ]
 
 
 def test_get_by_itag(cipher_signature):
@@ -143,7 +167,7 @@ def test_get_highest_resolution(cipher_signature):
 def test_filter_is_dash(cipher_signature):
     streams = cipher_signature.streams.filter(is_dash=False)
     itags = [s.itag for s in streams]
-    assert itags == [18, 22]
+    assert itags == [17, 18, 22]
 
 
 def test_get_audio_only(cipher_signature):
@@ -155,13 +179,13 @@ def test_get_audio_only_with_subtype(cipher_signature):
 
 
 def test_sequence(cipher_signature):
-    assert len(cipher_signature.streams) == 24
+    assert len(cipher_signature.streams) == 26
     assert cipher_signature.streams[0] is not None
 
 
 def test_otf(cipher_signature):
     non_otf = cipher_signature.streams.otf()
-    assert len(non_otf) == 24
+    assert len(non_otf) == 26
 
     otf = cipher_signature.streams.otf(True)
     assert len(otf) == 0
